@@ -7,11 +7,11 @@ use UNIVERSAL::require;
 use Scalar::Util qw/blessed/;
 use FormValidator::Lite::Constraint::Default;
 use FormValidator::Lite::Upload;
-use Class::Accessor::Lite;
+use Class::Accessor::Lite 0.05 (
+    rw => [qw/query/]
+);
 
-Class::Accessor::Lite->mk_accessors(qw/query/);
-
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 our $Rules;
 our $FileRules;
@@ -46,12 +46,14 @@ sub check {
             my $rule_name = ref($rule) ? $rule->[0]                        : $rule;
             my $args      = ref($rule) ? [ @$rule[ 1 .. scalar(@$rule)-1 ] ] : +[];
 
+            if ($FileRules->{$rule_name}) {
+                $_ = FormValidator::Lite::Upload->new($q, $key);
+            }
             my $is_ok = do {
                 if ((not (defined $_ && length $_)) && $rule_name !~ /^(NOT_NULL|NOT_BLANK|REQUIRED)$/) {
                     1;
                 } else {
                     if (my $file_rule = $FileRules->{$rule_name}) {
-                        local $_ = FormValidator::Lite::Upload->new($q, $key);
                         $file_rule->(@$args) ? 1 : 0;
                     } else {
                         my $code = $Rules->{$rule_name} or Carp::croak("unknown rule $rule_name");
@@ -258,6 +260,7 @@ IT'S IN BETA QUALITY. API MAY CHANGE IN FUTURE.
 Create a new instance.
 
 $q is query like object, such as Apache::Request, CGI.pm, Plack::Request.
+The object MUST have a C<< $q->parma >> method.
 
 =item $validator->query()
 
@@ -267,27 +270,34 @@ Getter/Setter for query like object.
 
 =item $validator->check(@rule_ary)
 
-This method do validation.
+    my $res = $validator->check(
+        name      => [qw/NOT_NULL/],
+        name_kana => [qw/NOT_NULL KATAKANA/],
+        {mails => [qw/mail1 mail2/]} => ['DUPLICATION'],
+    );
+
+This method do validation. You can write a rule in C<< @rule_ary >>. In above example code, I<name>
+is a parameter name, I<NOT_NULL>, I<KATAKANA> and I<DUPLICATION> are name of constraints.
 
 =item $validator->is_error($key)
 
-Return true value if parameter named $key got error.
+Return true value if parameter named C<< $key >> got error.
 
 =item $validator->is_valid()
 
-Return true value if $validator don't detects error.
+Return true value if C<< $validator >> don't detects error.
 
-This is same as !$validator->has_error().
+This is same as C<< !$validator->has_error() >>.
 
 =item $validator->has_error()
 
-Return true value if $validator detects error.
+Return true value if C<< $validator >> detects error.
 
-This is same as !$validator->is_valid().
+This is same as C<< !$validator->is_valid() >>.
 
 =item $validator->set_error($param, $rule_name)
 
-Set new error to parameter named $param. The rule name is  $rule_name.
+Set new error to parameter named C<<$param>>. The rule name is C<<$rule_name>>.
 
 =item $validator->errors()
 
@@ -309,7 +319,7 @@ There is a import style.
 
     use FormValidator::Lite qw/Date Email/;
 
-load constraint components named "FormValidator::Lite::Constraint::${name}".
+load constraint components named C<< "FormValidator::Lite::Constraint::${name}" >>.
 
 =item $validator->load_function_message($lang)
 
@@ -317,7 +327,7 @@ load constraint components named "FormValidator::Lite::Constraint::${name}".
 
 Load function message file.
 
-Currently, FormValidator::Lite::Messages::ja and FormValidator::Lite::Messages::en are available.
+Currently, L<FormValidator::Lite::Messages::ja> and L<FormValidator::Lite::Messages::en> are available.
 
 =item $validator->set_param_message($param => $message, ...)
     
@@ -352,7 +362,8 @@ Set error message for the $param and $func.
 
 =item my $errors = $validator->get_error_messages()
 
-Get whole error messages for $q in array/arrayref.
+Get whole error messages for C<<$q>> in array/arrayref.
+This method returns array in list context, otherwise HashRef.
 
 =item my $msg = $validator->get_error_message($param => $func)
 
@@ -388,6 +399,8 @@ craftworks
 
 nekokak
 
+tomi-ru
+
 =head1 SEE ALSO
 
 L<FormValidator::Simple>, L<Data::FormValidator>, L<HTML::FormFu>
